@@ -818,12 +818,15 @@ where
     }
 
     /// Check if this group is templated by checking whether the [context]
-    /// section contains this group's name as a key.
+    /// section contains any component of this group's name as a key.
     ///
     /// [context]: DTConfig::context
     pub fn is_templated(&self) -> bool {
         match self.context.0.as_table() {
-            Some(map) => map.get(&self.name.main()).is_some(),
+            Some(map) => self.name.0.components().any(|comp| {
+                map.get(&comp.as_os_str().to_string_lossy().to_string())
+                    .is_some()
+            }),
             None => false,
         }
     }
@@ -1552,17 +1555,21 @@ target = "target-ce59cb1aea35e22e43195d4a444ff2e7-dir""#,
     #[test]
     fn staging_is_file() -> Result<(), Report> {
         let staging_path = prepare_file(
-            get_testroot()
+            get_testroot("validation_physical")
                 .join("staging_is_file")
                 .join("staging-but-file"),
             0o644,
         )?;
         let base = prepare_directory(
-            get_testroot().join("staging_is_file").join("base"),
+            get_testroot("validation_physical")
+                .join("staging_is_file")
+                .join("base"),
             0o755,
         )?;
         let target = prepare_directory(
-            get_testroot().join("staging_is_file").join("target"),
+            get_testroot("validation_physical")
+                .join("staging_is_file")
+                .join("target"),
             0o755,
         )?;
 
@@ -1600,17 +1607,21 @@ target = "{}""#,
     #[test]
     fn staging_readonly() -> Result<(), Report> {
         let staging_path = prepare_directory(
-            get_testroot()
+            get_testroot("validation_physical")
                 .join("staging_readonly")
                 .join("staging-but-readonly"),
             0o555,
         )?;
         let base = prepare_directory(
-            get_testroot().join("staging_readonly").join("base"),
+            get_testroot("validation_physical")
+                .join("staging_readonly")
+                .join("base"),
             0o755,
         )?;
         let target_path = prepare_directory(
-            get_testroot().join("staging_readonly").join("target"),
+            get_testroot("validation_physical")
+                .join("staging_readonly")
+                .join("target"),
             0o755,
         )?;
 
@@ -1647,7 +1658,7 @@ target = "{}""#,
     #[test]
     fn target_is_file() -> Result<(), Report> {
         let target_path = prepare_file(
-            get_testroot()
+            get_testroot("validation_physical")
                 .join("target_is_file")
                 .join("target-but-file"),
             0o755,
@@ -1682,11 +1693,13 @@ target = "{}""#,
     fn target_readonly() -> Result<(), Report> {
         // setup
         let base = prepare_directory(
-            get_testroot().join("target_readonly").join("base"),
+            get_testroot("validation_physical")
+                .join("target_readonly")
+                .join("base"),
             0o755,
         )?;
         let target_path = prepare_directory(
-            get_testroot()
+            get_testroot("validation_physical")
                 .join("target_readonly")
                 .join("target-but-readonly"),
             0o555,
@@ -1723,7 +1736,7 @@ target = "{}""#,
     fn identical_configured_base_and_target_in_local() -> Result<(), Report> {
         // setup
         let base = prepare_directory(
-            get_testroot()
+            get_testroot("validation_physical")
                 .join("local_group_has_same_base_and_target")
                 .join("base-and-target"),
             0o755,
@@ -1761,7 +1774,9 @@ target = "{}"
     #[test]
     fn base_unreadable() -> Result<(), Report> {
         let base = prepare_file(
-            get_testroot().join("base_unreadable").join("base-but-file"),
+            get_testroot("validation_physical")
+                .join("base_unreadable")
+                .join("base-but-file"),
             0o311,
         )?;
         if let Err(err) = DTConfig::from_str(&format!(
@@ -1786,7 +1801,7 @@ target = ".""#,
         }
 
         let base = prepare_directory(
-            get_testroot()
+            get_testroot("validation_physical")
                 .join("base_unreadable")
                 .join("base-unreadable"),
             0o311,
