@@ -140,15 +140,16 @@ pub fn host_specific_suffix(hostname_sep: &str) -> String {
 #[cfg(test)]
 pub(crate) mod testing {
     use std::{
-        fs::Permissions, os::unix::prelude::PermissionsExt, path::PathBuf,
+        ffi::OsString, fs::Permissions, os::unix::prelude::PermissionsExt,
+        path::PathBuf, str::FromStr,
     };
 
     use color_eyre::Report;
 
-    const TESTROOT: &str = "/tmp/dt-testing/syncing";
+    const TESTROOT: &str = "/tmp/dt-testing";
 
-    pub fn get_testroot() -> PathBuf {
-        TESTROOT.into()
+    pub fn get_testroot(top_level: &str) -> PathBuf {
+        PathBuf::from_str(TESTROOT).unwrap().join(top_level)
     }
 
     pub fn prepare_directory(
@@ -174,6 +175,18 @@ pub(crate) mod testing {
         std::fs::set_permissions(&abspath, Permissions::from_mode(mode))?;
         Ok(abspath)
     }
+
+    pub fn gethostname() -> OsString {
+        "r2d2".into()
+    }
+
+    pub fn get_current_uid() -> users::uid_t {
+        418
+    }
+
+    pub fn get_current_username() -> Option<OsString> {
+        Some("luke".into())
+    }
 }
 
 // Author: Blurgy <gy@blurgy.xyz>
